# district42

[![Codecov](https://img.shields.io/codecov/c/github/tsv1/district42/master.svg?style=flat-square)](https://codecov.io/gh/tsv1/district42)
[![PyPI](https://img.shields.io/pypi/v/district42.svg?style=flat-square)](https://pypi.python.org/pypi/district42/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/district42?style=flat-square)](https://pypi.python.org/pypi/district42/)
[![Python Version](https://img.shields.io/pypi/pyversions/district42.svg?style=flat-square)](https://pypi.python.org/pypi/district42/)

`district42` is a data description language designed for defining data models. It provides a simple and expressive way to define the structure and constraints of your data.

This package serves as the foundation for the [d42 package](https://pypi.org/project/d42/). For a quick-start guide and detailed documentation, please visit the official documentation at [d42.vedro.io/docs/quick-start](https://d42.vedro.io/docs/quick-start)
